pub enum NlError {
NonLinearSolverError(NonLinearSolverError),
LaError(LaError),
Other(String),
}Expand description
Error type for the diffsol non-linear solver crate (diffsol-nl).
This wraps the errors that can occur in the non-linear solver layer, as well as
the linear-algebra errors produced by the underlying diffsol_la linear solvers.
It is re-exported by the diffsol crate and can be converted into diffsol’s
top-level error type.
Variants